@@ -104,7 +104,8 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 
 	/* Auction number */
 	memReset(mp);
-	if (memStr(mp, "\"BHitemNo\"")) {
+	if (memStr(mp, "\"BHCtBidLabel\"") ||
+		memStr(mp, "\"BHitemNo\"")) { /* obsolete as of 2.22 */
 		memChr(mp, '>');
 		memSkip(mp, 1);
 		line = getNonTag(mp);	/* Item number: */
@@ -132,7 +133,9 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 
 	/* Auction title */
 	memReset(mp);
-	if (memStr(mp, "\"BHitemTitle\"")) {
+	if (memStr(mp, "\"itemTitle\"") ||
+		memStr(mp, "\"BHitemTitle\"") || /* obsolete as of 2.22 */
+		memStr(mp, "\"BHitemDesc\"")) {	/* obsolete before 2.22 */
 		memChr(mp, '>');
 		memSkip(mp, 1);
 		line = getNonTag(mp);	/* title */
@@ -141,15 +144,6 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "item title not found");
 			return auctionError(aip, ae_baditem, NULL);
 		}
-	} else if (memStr(mp, "\"BHitemDesc\"")) {
-		memChr(mp, '>');
-		memSkip(mp, 1);
-		line = getNonTag(mp);	/* title */
-		if (!line || !strcmp(line, "See item description")) {
-			log(("parseBidHistory(): No item title, place 2"));
-			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "item description not found");
-			return auctionError(aip, ae_baditem, NULL);
-		}
 	} else {
 		log(("parseBidHistory(): BHitemTitle not found"));
 		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "item title or description not found");
@@ -234,6 +228,14 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		memSkip(mp, 1);
 		free(aip->remainRaw);
 		aip->remainRaw = myStrdup(getNonTag(mp));
+		if (!strcasecmp(aip->remainRaw, "Duration:")) {
+			/* Duration may follow Time left.  If we
+			 * see this, time left must be empty.  Assume 1 second.
+			 */
+			free(aip->remainRaw);
+			aip->remainRaw = myStrdup("");
+			aip->remain = 1;
+                }
 		if (!strcasecmp(aip->remainRaw, "Refresh")) {
 			/* Refresh is the label on the next button.  If we
 			 * see this, time left must be empty.  Assume 1 second.
@@ -627,6 +629,10 @@ getSeconds(char *timestr)
 	long accum = 0;
 	long num;
 
+	/* skip leading space */
+	while (*timestr && isspace((int)*timestr))
+		++timestr;
+
 	/* Time is blank in transition between "Time left: 1 seconds" and
 	 * "Time left: auction has ended".  I don't know if blank means
 	 * the auction is over, or it still running with less than 1 second.
